@@ -242,8 +242,8 @@ def test_map_list_urls_cache():
     """
     Test for https://github.com/sunpy/sunpy/issues/4006
     """
-    urls = ['http://jsoc.stanford.edu/SUM80/D136597189/S00000/image_lev1.fits',
-            'http://jsoc.stanford.edu/SUM79/D136597240/S00000/image_lev1.fits']
+    urls = ['https://github.com/sunpy/data/raw/main/sunpy/v1/AIA20110607_063305_0094_lowres.fits',
+            'https://github.com/sunpy/data/raw/main/sunpy/v1/AIA20110607_063305_0094_lowres.fits']
     sunpy.map.Map(urls)
 
 
